Output gradient — BAGO 0.0.1 documentation

# Output gradient

outputConfig(name, timePoints, gradient)

  Function to output the gradient to a csv file.

  Parameters:

    - name – str. Name of the file to be output.

    - timePoints – numpy array. Time points for the gradient.

    - gradient – numpy array. Gradient to be output.

To use this function:

    from bago import rawDataHelper
    rawDataHelper.outputConfig('gradient.csv', timePoints, gradient)